@@ -1,6 +1,13 @@
-# $Id: make.contrasts.R,v 1.1 2002/10/29 23:00:43 warnes Exp $
+# $Id: make.contrasts.R,v 1.2 2003/01/30 14:58:31 warnes Exp $
 #
 # $Log: make.contrasts.R,v $
+# Revision 1.2  2003/01/30 14:58:31  warnes
+#
+# - Added explicit check to ensure that the number of specified
+#   contrasts is less than or equal to the ncol - 1.  Previously, this
+#   failed with an obtuse error message when the contrast matrix had row
+#   names, and silently dropped contrasts over ncol-1.
+#
 # Revision 1.1  2002/10/29 23:00:43  warnes
 #
 # - Moved make.contrasts to a separate file.
@@ -16,6 +23,9 @@
 {
   if(!is.matrix(contr))
     contr <- matrix(contr,ncol=length(contr))
+
+  if(nrow(contr)+1 > how.many)
+    stop("Too many contrasts specified. Must be less than the number of factor levels (columns).")
   
   value <- as.matrix(ginv(contr))  # requires library(MASS)
   if (nrow(value) != how.many) 
