@@ -1,9 +1,8 @@
-
 .First.lib <- function(libname, pkgname)
   {
     if(is.R())
       {
-        library(mva)
-        library(MASS)
+        library(stats)
+        library(MASS)   
       }
   }
